pub struct RunHandle {
pub root: PathBuf,
pub name: String,
pub agent: Option<AcpAgentConfig>,
pub mcp_config: Option<McpConfig>,
pub mcp_diagnostics: Vec<String>,
pub prompt: String,
pub cancel: CancelToken,
}Expand description
Handle for a client-side ACP run.
Fields
root: PathBufname: Stringagent: Option<AcpAgentConfig>mcp_config: Option<McpConfig>mcp_diagnostics: Vec<String>prompt: Stringcancel: CancelTokenImplementations
Sourceimpl RunHandle
impl RunHandle
Sourcepub fn new(
root: PathBuf,
name: String,
agent: Option<AcpAgentConfig>,
prompt: String,
) -> Self
pub fn new( root: PathBuf, name: String, agent: Option<AcpAgentConfig>, prompt: String, ) -> Self
Build an ACP run handle for acp:<name>.
Sourcepub fn with_mcp_config(self, mcp_config: McpConfig) -> Self
pub fn with_mcp_config(self, mcp_config: McpConfig) -> Self
Attach effective MCP config that should be offered to the ACP agent.
Sourcepub fn with_mcp_diagnostics(self, diagnostics: Vec<String>) -> Self
pub fn with_mcp_diagnostics(self, diagnostics: Vec<String>) -> Self
Attach redacted MCP config loader diagnostics.
Sourcepub fn spawn(self) -> Receiver<AgentEvent>
pub fn spawn(self) -> Receiver<AgentEvent>
Spawn an ACP run and return the normal agent event receiver.