pub struct ArtifactWrite {
pub metadata: ArtifactMetadata,
pub bounded_lines: Vec<String>,
}Expand description
A successful artifact write, including the safe projection used by the UI.
Fields
metadata: ArtifactMetadataPersisted metadata.
bounded_lines: Vec<String>Bounded redacted lines suitable for display or compatibility records.