pub fn collect(cwd: &Path) -> Option<GitStatusSummary>Expand description
Collect a semantic status summary without changing the workspace.
pub fn collect(cwd: &Path) -> Option<GitStatusSummary>Collect a semantic status summary without changing the workspace.