pub enum TranscriptPosition {
Banner {
row: usize,
},
Entry {
entry_index: usize,
row_in_entry: usize,
},
}Expand description
Stable transcript position used while the reader is away from the tail.
Variants
Banner
A row in the startup banner, before transcript entries exist.
Entry
A logical rendered row within an append-only transcript entry.