Module highlight

Module highlight 

Renderer-native syntax highlighting using syntect.

Functions

highlight_lines
Highlight a code string into rows of renderer spans.
path_extension_language
Map a file path extension to a syntect language token.
syntax_for
Guess a syntax definition from a file extension or language name.
tool_output_language
Determine the syntax highlighting language for a tool’s output.