pub fn export_item(item: &ContextItem) -> ExportContextItemExpand description
Return the inspection details used by both the table and export.
pub fn export_item(item: &ContextItem) -> ExportContextItemReturn the inspection details used by both the table and export.