Module fuzzy

Module fuzzy 

Structs

FuzzyMatch
Case-insensitive fuzzy subsequence matching.

Functions

fuzzy_filter
Filter items by fuzzy match, returning each result with matched character indices so callers can highlight which characters matched.
fuzzy_match