pub struct SelfKnowledgeSnapshot {
pub identity: AppIdentitySnapshot,
pub runtime: RuntimeSnapshot,
pub inventory: KnowledgeInventorySnapshot,
pub diagnostics: Vec<String>,
pub context_dashboard: Option<String>,
}Fields
identity: AppIdentitySnapshotruntime: RuntimeSnapshotinventory: KnowledgeInventorySnapshotdiagnostics: Vec<String>context_dashboard: Option<String>Compact context dashboard from the context selection ledger, when a projection is attached to the prompt bundle.
Implementations
Sourceimpl SelfKnowledgeSnapshot
impl SelfKnowledgeSnapshot
pub fn new( identity: AppIdentitySnapshot, runtime: RuntimeSnapshot, inventory: KnowledgeInventorySnapshot, diagnostics: Vec<String>, ) -> Self
Sourcepub fn with_context_dashboard(self, dashboard: impl Into<String>) -> Self
pub fn with_context_dashboard(self, dashboard: impl Into<String>) -> Self
Attach a compact context dashboard string rendered from the context selection ledger.
pub fn render_model_visible(&self) -> String
pub fn startup_sections(&self) -> Vec<StartupSection>