pub enum ProviderError {
MissingApiKey {
env: &'static str,
},
InvalidModelId {
provider: &'static str,
prefix: &'static str,
model: String,
},
Http(String),
Status {
code: u16,
body: String,
},
Auth(String),
AuthUnavailable(String),
Json(String),
}Expand description
Shared provider request error shape.
Variants
MissingApiKey
Required API key environment variable is not set.
InvalidModelId
The selected model id is not valid for this provider.
Http(String)
HTTP transport error.
Status
HTTP status error (non-2xx response).
Auth(String)
Authentication error before a provider request can be sent.
Credential verification could not complete because a dependency is unavailable.
Json(String)
JSON serialization/deserialization error.
Implementations
Sourceimpl ProviderError
impl ProviderError
pub fn missing_api_key(env: &'static str) -> Self
pub fn invalid_model_id( provider: &'static str, prefix: &'static str, model: &str, ) -> Self
Sourcepub fn is_credential_rejected(&self) -> bool
pub fn is_credential_rejected(&self) -> bool
Whether the provider explicitly rejected the current credential.
pub fn is_retryable(&self) -> bool
pub fn failure_message(&self, rate_limit_message: &str) -> String