pub struct ModelInfo {
pub name: String,
pub display_name: String,
pub description: String,
pub base_model: BaseModel,
pub capabilities: Capabilities,
pub benchmarks: Value,
}Expand description
Model information from GET /v1/models/info.
Umans may add optional metadata fields as its model catalogue changes. The provider keeps the fields needed by setup and request lowering, while tolerating omitted descriptive fields so a catalogue update does not make an otherwise usable provider unavailable.
Fields
name: Stringdisplay_name: Stringdescription: Stringbase_model: BaseModelcapabilities: Capabilitiesbenchmarks: ValueTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ModelInfo
impl<'de> Deserialize<'de> for ModelInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for ModelInfo