pub async fn run_stdio(config: ServerConfig) -> Result<()>Expand description
Run thndrs acp serve over stdio until the ACP connection closes.
pub async fn run_stdio(config: ServerConfig) -> Result<()>Run thndrs acp serve over stdio until the ACP connection closes.