ServerConfig

Struct ServerConfig 

pub struct ServerConfig {
    pub cwd: PathBuf,
    pub model: String,
    pub websearch: String,
    pub websearch_url: Option<String>,
    pub reasoning_effort: ReasoningEffort,
    pub reasoning_summary: ReasoningSummary,
    pub session_dir: Option<PathBuf>,
}
Runtime configuration accepted by the ACP agent binary.

Fields

cwd: PathBuf

Workspace directory used for ACP sessions when the client does not provide a more specific root.

model: String

Provider model selected for future harness turns.

websearch: String

Web search policy label selected for future harness turns.

websearch_url: Option<String>

Optional base URL for the SearXNG backend.

reasoning_effort: ReasoningEffort

Default reasoning effort for ChatGPT Codex GPT-5.6 sessions.

reasoning_summary: ReasoningSummary

Default reasoning-summary policy for ChatGPT Codex GPT-5.6 sessions.

session_dir: Option<PathBuf>

Optional append-only session directory.

Implementations

Source

impl ServerConfig

pub fn new( cwd: PathBuf, model: String, websearch: String, session_dir: Option<PathBuf>, ) -> Self

Build a server config from parsed binary flags.

pub fn with_reasoning( self, effort: ReasoningEffort, summary: ReasoningSummary, ) -> Self

Apply resolved reasoning defaults from local configuration.

pub fn with_search_url(self, url: Option<String>) -> Self

Apply the configured SearXNG base URL.