pub struct ToolIterationBudget { /* private fields */ }Expand description
Bounded tool-batch budget for one agent turn.
Implementations
Sourceimpl ToolIterationBudget
impl ToolIterationBudget
Sourcepub fn new(
segment_limit: usize,
continuation_limit: usize,
) -> ToolIterationBudget
pub fn new( segment_limit: usize, continuation_limit: usize, ) -> ToolIterationBudget
Create a budget with a segment limit and total continuation limit.
Sourcepub fn record_tool_batch(&mut self)
pub fn record_tool_batch(&mut self)
Record a completed provider-requested tool batch.
Sourcepub fn before_provider_request(&mut self) -> ToolBudgetDecision
pub fn before_provider_request(&mut self) -> ToolBudgetDecision
Decide whether the next provider request fits the remaining budget.
Sourcepub const fn total_batches(&self) -> usize
pub const fn total_batches(&self) -> usize
Return the total number of completed tool batches.
Sourcepub const fn continuations_used(&self) -> usize
pub const fn continuations_used(&self) -> usize
Return the number of consumed continuation segments.