iocraft adapter for bounded surface rendering.
This module is the only place the direct TUI renderer calls iocraft. It
renders declarative iocraft elements into an inspectable canvas, then
converts the canvas back into the existing Row contract. It does not call
iocraft render loops, fullscreen mode, stdout, or stderr.
Structs
- Iocraft
Surface Renderer - iocraft-backed renderer for bounded focused surfaces.
Functions
- render_
surface - Render a semantic focused surface through iocraft.
- transcript_
lens_ rows - Render a bounded transcript/detail lens with iocraft.