Module fuzzy
thndrs_
lib
0.1.0
Module fuzzy
Module Items
Structs
Functions
In crate thndrs_
lib
thndrs_lib
Module
fuzzy
Structs

Fuzzy
Match
Case-insensitive fuzzy subsequence matching.
Functions

fuzzy_
filter
Filter items by fuzzy match, returning each result with matched character indices so callers can highlight which characters matched.
fuzzy_
match