pub struct ChatGptCodexClient { /* private fields */ }Expand description
Concrete ChatGPT Codex API client.
Implementations
Sourceimpl ChatGptCodexClient
impl ChatGptCodexClient
Sourcepub fn from_env_or_dotenv(_workspace_root: &Path) -> Result<Self>
pub fn from_env_or_dotenv(_workspace_root: &Path) -> Result<Self>
Create a client from CHATGPT_CODEX_ACCESS_TOKEN or ~/.thndrs/auth.json.
Sourcepub fn new(base_url: &str, auth: ChatGptCodexAuth) -> Self
pub fn new(base_url: &str, auth: ChatGptCodexAuth) -> Self
Create a client with explicit auth material.
Sourcepub fn build_responses_headers(&self) -> Vec<(String, String)>
pub fn build_responses_headers(&self) -> Vec<(String, String)>
Build the headers for a streaming Responses request.
Sourcepub fn build_responses_request_body(
model: &str,
messages: &[ProviderMessage],
tools: Option<&Value>,
) -> Result<Value>
pub fn build_responses_request_body( model: &str, messages: &[ProviderMessage], tools: Option<&Value>, ) -> Result<Value>
Build a Responses-like streaming request body.
Sourcepub fn build_responses_request_body_with_reasoning(
model: &str,
messages: &[ProviderMessage],
tools: Option<&Value>,
effort: ReasoningEffort,
summary: ReasoningSummary,
continuation: &ProviderContinuation,
) -> Result<Value>
pub fn build_responses_request_body_with_reasoning( model: &str, messages: &[ProviderMessage], tools: Option<&Value>, effort: ReasoningEffort, summary: ReasoningSummary, continuation: &ProviderContinuation, ) -> Result<Value>
Build a Responses streaming request body for the ChatGPT Codex route.
Sourcepub fn build_openai_responses_request_body(
raw_model: &str,
messages: &[ProviderMessage],
tools: Option<&Value>,
effort: ReasoningEffort,
summary: ReasoningSummary,
continuation: &ProviderContinuation,
) -> Value
pub fn build_openai_responses_request_body( raw_model: &str, messages: &[ProviderMessage], tools: Option<&Value>, effort: ReasoningEffort, summary: ReasoningSummary, continuation: &ProviderContinuation, ) -> Value
Build a standard Responses request for an already-normalized model id.
Sourcepub fn probe_authentication(&self) -> Result<()>
pub fn probe_authentication(&self) -> Result<()>
Verify the configured credential against the lightweight model catalog.
Sourcepub fn send_streaming_request(
&self,
model: &str,
messages: &[ProviderMessage],
tools: Option<&Value>,
effort: ReasoningEffort,
summary: ReasoningSummary,
continuation: &ProviderContinuation,
) -> Result<Response<Body>>
pub fn send_streaming_request( &self, model: &str, messages: &[ProviderMessage], tools: Option<&Value>, effort: ReasoningEffort, summary: ReasoningSummary, continuation: &ProviderContinuation, ) -> Result<Response<Body>>
Send a streaming request to POST /responses.